==> james-project-3.7.6-source-release.zip: james-project/server/queue/queue-rabbitmq/src/main/java/org/apache/james/queue/rabbitmq/view/api/MailQueueView.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.queue.rabbitmq.view.api;

import java.time.Instant;

import org.apache.james.queue.api.ManageableMailQueue;
import org.apache.james.queue.rabbitmq.EnqueueId;
import org.apache.james.queue.rabbitmq.EnqueuedItem;
import org.apache.james.queue.rabbitmq.MailQueueName;
import org.reactivestreams.Publisher;

import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

public interface MailQueueView<V extends ManageableMailQueue.MailQueueItemView> {

    interface Factory {
        MailQueueView create(MailQueueName mailQueueName);
    }

    void initialize(MailQueueName mailQueueName);

    Mono<Void> storeMail(EnqueuedItem enqueuedItem);

    Publisher<Long> delete(DeleteCondition deleteCondition);

    Mono<Boolean> isPresent(EnqueueId id);

    ManageableMailQueue.MailQueueIterator browse();

    Flux<V> browseReactive();

    Flux<V> browseOlderThanReactive(Instant olderThan);

    long getSize();
}

==> james-project-3.8.0-source-release.zip: james-project/server/queue/queue-rabbitmq/src/main/java/org/apache/james/queue/rabbitmq/view/api/MailQueueView.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.queue.rabbitmq.view.api;

import java.time.Instant;

import org.apache.james.queue.api.ManageableMailQueue;
import org.apache.james.queue.rabbitmq.EnqueueId;
import org.apache.james.queue.rabbitmq.EnqueuedItem;
import org.apache.james.queue.rabbitmq.MailQueueName;

import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

public interface MailQueueView<V extends ManageableMailQueue.MailQueueItemView> {

    interface Factory {
        MailQueueView create(MailQueueName mailQueueName);
    }

    void initialize(MailQueueName mailQueueName);

    Mono<Void> storeMail(EnqueuedItem enqueuedItem);

    long delete(DeleteCondition deleteCondition);

    Mono<Boolean> isPresent(EnqueueId id);

    ManageableMailQueue.MailQueueIterator browse();

    Flux<V> browseReactive();

    Flux<V> browseOlderThanReactive(Instant olderThan);

    long getSize();

    Mono<Long> getSizeReactive();
}
